@@ -33,12 +33,12 @@ from sklearn.utils.validation import check_is_fitted, check_memory
 __all__ = ["DAG", "DAGStep"]
 
 
-def _get_columns(X, dep, cols, is_root, axis=1):
+def _get_columns(X, dep, cols, is_root, dep_is_passthrough, axis=1):
     if callable(cols):
         # sklearn.compose.make_column_selector
         cols = cols(X)
 
-    if not is_root:
+    if not is_root and not dep_is_passthrough:
         # The DAG will prepend output columns with the step name, so add this in to any
         # dep columns if missing. This helps keep user-provided deps readable.
         if isinstance(cols, str):
@@ -60,7 +60,14 @@ def _stack_inputs(dag, X, node):
     deps = {node.name: None} if node.is_root else node.deps
 
     cols = [
-        _get_columns(X[dep], dep, cols, node.is_root, axis=1)
+        _get_columns(
+            X[dep],
+            dep,
+            cols,
+            node.is_root,
+            _is_passthrough(dag.graph_.nodes[dep]["step"].estimator),
+            axis=1,
+        )
         for dep, cols in deps.items()
     ]
 
